bytemap.core

Text-based canvas using braille characters.

Bytemap creates bitmaps using Unicode braille characters, where each character represents a 2x4 grid of pixels. This enables reasonably high-resolution text-based graphics in terminal output.

Text-based canvas using braille characters.

Bytemap creates bitmaps using Unicode braille characters, where each character
represents a 2x4 grid of pixels. This enables reasonably high-resolution
text-based graphics in terminal output.
raw docstring

bytemap.util

Low-level utility functions for bit manipulation and numeric operations.

Low-level utility functions for bit manipulation and numeric operations.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries