Text-based canvas using braille characters.
Bytemap creates bitmaps using Unicode braille characters, where each character represents a 2x4 grid of pixels. This enables reasonably high-resolution text-based graphics in terminal output.
Text-based canvas using braille characters. Bytemap creates bitmaps using Unicode braille characters, where each character represents a 2x4 grid of pixels. This enables reasonably high-resolution text-based graphics in terminal output.
Low-level utility functions for bit manipulation and numeric operations.
Low-level utility functions for bit manipulation and numeric operations.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |