Low-level utility functions for bit manipulation and numeric operations.
Low-level utility functions for bit manipulation and numeric operations.
(bar-value bins start end)Weighted average of bins for a bar spanning [start, end).
Weighted average of bins for a bar spanning [start, end).
(bin-overlap i start end)Proportion of bin i overlapping the interval [start, end).
Proportion of bin i overlapping the interval [start, end).
(downsample-histogram bins bar-count)Reduce bins to bar-count values by weighted averaging.
Reduce `bins` to `bar-count` values by weighted averaging.
(format-float x)Format a floating point number.
Format a floating point number.
(idiv a b)Returns the floor of a divided by b.
Returns the floor of a divided by b.
(set-bit num i value)Sets or clears bit i in num.
Sets or clears bit i in num.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |