bytemap.util

Low-level utility functions for bit manipulation and numeric operations.

Low-level utility functions for bit manipulation and numeric operations.
raw docstring

calculate-meanclj/s

(calculate-mean xs)
source

calculate-std-devclj/s

(calculate-std-dev xs & rest)
source

format-floatclj/s

(format-float x)

Format a floating point number.

Format a floating point number.
sourceraw docstring

idivclj/s

(idiv a b)

Returns the floor of a divided by b.

Returns the floor of a divided by b.
sourceraw docstring

set-bitclj/s

(set-bit num i value)

Sets or clears bit i in num.

Sets or clears bit i in num.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries