Low-level utility functions for bit manipulation and numeric operations.
Low-level utility functions for bit manipulation and numeric operations.
(format-float x)Format a floating point number.
Format a floating point number.
(idiv a b)Returns the floor of a divided by b.
Returns the floor of a divided by b.
(set-bit num i value)Sets or clears bit i in num.
Sets or clears bit i in num.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |